@@ -1,6 +1,7 @@
 from .request.criar_boleto import CriarBoleto
 from .request.busca_boleto import BuscaBoleto
 from .request.numero_doc import NumeroDoc
+from .request.baixar_boleto import BaixarBoleto
 
 
 class PlugBoleto(object):
@@ -26,7 +27,12 @@ class PlugBoleto(object):
 
         return request.execute(id_integracao)
 
-    def link_boleto(self, id_integracao):
-        uri = '%sboletos/impressao/%s' % (self.environment.api, id_integracao)
+    def baixar_boleto(self, id_integracao):
+        request = BaixarBoleto(self.authorize, self.environment)
+
+        return request.execute(id_integracao)
+
+    def link_boleto(self, id_impressao):
+        uri = '%sboletos/impressao/%s' % (self.environment.api, id_impressao)
 
         return uri
